Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GeneratePrefixedHash ¶
Types ¶
type Signer ¶
type Signer struct {
// contains filtered or unexported fields
}
func NewSignerFromKeystore ¶
func (*Signer) SignEthMessage ¶
input data: a byte array of raw message to be signed return a byte array signature in the R,S,V format
Click to show internal directories.
Click to hide internal directories.